[![Build Status](https://travis-ci.com/CohenLabPrinceton/Ventilator-Dev.svg?branch=master)](https://travis-ci.com/CohenLabPrinceton/Ventilator-Dev)
[![Coverage Status](https://coveralls.io/repos/github/CohenLabPrinceton/Ventilator-Dev/badge.svg)](https://coveralls.io/github/CohenLabPrinceton/Ventilator-Dev)
[![Documentation Status](https://readthedocs.org/projects/ventilator/badge/?version=latest)](https://ventilator.readthedocs.io/en/latest/?badge=latest)

# Ventilator-Dev
Raspberry pi code for controlling the rapid-deploy critical care ventilator 
